==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/Databases/ServiceSqlDatabase.md <==
# ServiceSqlDatabase


```text
azure-4/Item/Databases/ServiceSqlDatabase
```

```text
include('azure-4/Item/Databases/ServiceSqlDatabase')
```



| Illustration | ServiceSqlDatabase | ServiceSqlDatabaseCard | ServiceSqlDatabaseGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Databases/ServiceSqlDatabase.png) | ![illustration for ServiceSqlDatabase](../../../azure-4/Item/Databases/ServiceSqlDatabase.Local.png) | ![illustration for ServiceSqlDatabaseCard](../../../azure-4/Item/Databases/ServiceSqlDatabaseCard.Local.png) | ![illustration for ServiceSqlDatabaseGroup](../../../azure-4/Item/Databases/ServiceSqlDatabaseGroup.Local.png) |




## ServiceSqlDatabase

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabase
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabase('ServiceSqlDatabase', 'Service Sql Database', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabase
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabase('ServiceSqlDatabase', 'Service Sql Database', 'an optional tech label')
@enduml
```

## ServiceSqlDatabaseCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabaseCard
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabaseCard('ServiceSqlDatabaseCard', 'Service Sql Database Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabaseCard
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabaseCard('ServiceSqlDatabaseCard', 'Service Sql Database Card', 'an optional description')
@enduml
```

## ServiceSqlDatabaseGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabaseGroup
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabaseGroup('ServiceSqlDatabaseGroup', 'Service Sql Database Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabaseGroup
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabaseGroup('ServiceSqlDatabaseGroup', 'Service Sql Database Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/azure-4/Item/Databases/ServiceSqlDatabase.md <==
# ServiceSqlDatabase


```text
azure-4/Item/Databases/ServiceSqlDatabase
```

```text
include('azure-4/Item/Databases/ServiceSqlDatabase')
```



| Illustration | ServiceSqlDatabase | ServiceSqlDatabaseCard | ServiceSqlDatabaseGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Databases/ServiceSqlDatabase.png) | ![illustration for ServiceSqlDatabase](../../../azure-4/Item/Databases/ServiceSqlDatabase.Local.png) | ![illustration for ServiceSqlDatabaseCard](../../../azure-4/Item/Databases/ServiceSqlDatabaseCard.Local.png) | ![illustration for ServiceSqlDatabaseGroup](../../../azure-4/Item/Databases/ServiceSqlDatabaseGroup.Local.png) |




## ServiceSqlDatabase

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabase
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabase('ServiceSqlDatabase', 'Service Sql Database', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabase
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabase('ServiceSqlDatabase', 'Service Sql Database', 'an optional tech label')
@enduml
```

## ServiceSqlDatabaseCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabaseCard
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabaseCard('ServiceSqlDatabaseCard', 'Service Sql Database Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabaseCard
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabaseCard('ServiceSqlDatabaseCard', 'Service Sql Database Card', 'an optional description')
@enduml
```

## ServiceSqlDatabaseGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabaseGroup
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabaseGroup('ServiceSqlDatabaseGroup', 'Service Sql Database Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceSqlDatabaseGroup
include('azure-4/Item/Databases/ServiceSqlDatabase')

' renders the element
ServiceSqlDatabaseGroup('ServiceSqlDatabaseGroup', 'Service Sql Database Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
